@@ -62,7 +62,6 @@ The formal syntax of a section specification is:
 =over 4
 
 =item
-
 I<head1-title-regexp>/I<head2-title-regexp>/...
 
 =back
@@ -372,7 +371,7 @@ The base class implementation of this method returns the given text.
 
 =cut
 
-sub preprocess_line($text) {
+sub preprocess_line {
     my $self = shift;
     my $text = shift;
     return  $text;
